@@ -10,8 +10,11 @@ pub use traits::ArelAble;
 
 pub use arel_macro::arel;
 
+pub use regex;
+pub use anyhow;
+pub use chrono;
 pub use async_trait;
 pub use serde_json;
-pub use anyhow;
 pub use sqlx;
+
 pub mod prelude;
\ No newline at end of file
