@@ -3,7 +3,7 @@ use std::marker::PhantomData;
 use serde_json::{Value as Json};
 use crate::traits::ArelAble;
 use crate::statements::{StatementAble, r#where::{self, Where}, Order, Limit, Offset, helpers::{self, and}};
-use crate::nodes::{SqlLiteral};
+use crate::collectors::Sql;
 
 #[derive(Clone, Debug)]
 pub struct DeleteStatement<M: ArelAble> {
@@ -31,31 +31,31 @@ impl<M> DeleteStatement<M> where M: ArelAble {
         self.wheres.push(Where::<M>::new(condition, ops));
         self
     }
-    pub fn get_where_sql(&self) -> anyhow::Result<Option<SqlLiteral>> {
+    pub fn get_where_sql(&self) -> anyhow::Result<Option<Sql>> {
         if self.r#wheres.len() == 0 {
             Ok(None)
         } else {
-            Ok(Some(SqlLiteral::new(and::to_sql(&self.r#wheres)?)))
+            Ok(Some(and::to_sql(&self.r#wheres)?))
         }
     }
     pub fn order(&mut self, condition: Json) -> &mut Self {
         self.orders.push(Order::new(condition));
         self
     }
-    pub fn get_order_sql(&self) -> anyhow::Result<Option<SqlLiteral>> {
+    pub fn get_order_sql(&self) -> anyhow::Result<Option<Sql>> {
         if self.orders.len() == 0 {
             Ok(None)
         } else {
-            Ok(Some(SqlLiteral::new(helpers::inject_join(&self.orders, ", ")?)))
+            Ok(Some(helpers::inject_join(&self.orders, ", ")?))
         }
     }
     pub fn limit(&mut self, condition: usize) -> &mut Self {
         self.limit = Some(Limit::new(condition));
         self
     }
-    pub fn get_limit_sql(&self) -> anyhow::Result<Option<SqlLiteral>> {
+    pub fn get_limit_sql(&self) -> anyhow::Result<Option<Sql>> {
         if let Some(limit) = &self.limit {
-            Ok(Some(SqlLiteral::new(limit.to_sql()?)))
+            Ok(Some(limit.to_sql()?))
         } else {
             Ok(None)
         }
@@ -64,9 +64,9 @@ impl<M> DeleteStatement<M> where M: ArelAble {
         self.offset = Some(Offset::new(condition));
         self
     }
-    pub fn get_offset_sql(&self) -> anyhow::Result<Option<SqlLiteral>> {
+    pub fn get_offset_sql(&self) -> anyhow::Result<Option<Sql>> {
         if let Some(offset) = &self.offset {
-            Ok(Some(SqlLiteral::new(offset.to_sql()?)))
+            Ok(Some(offset.to_sql()?))
         } else {
             Ok(None)
         }
