@@ -3,7 +3,7 @@ use serde_json::{Value as Json};
 use std::marker::PhantomData;
 use std::default::Default;
 use crate::traits::ArelAble;
-use crate::nodes::{SqlLiteral};
+use crate::collectors::Sql;
 
 #[derive(Debug, Clone)]
 pub struct InsertStatement<M: ArelAble> {
@@ -25,11 +25,11 @@ impl<M> InsertStatement<M> where M: ArelAble {
         self.insert = Some(Insert::new(condition));
         self
     }
-    pub fn get_insert_sql(&self) -> anyhow::Result<Option<SqlLiteral>> {
+    pub fn get_insert_sql(&self) -> anyhow::Result<Option<Sql>> {
         if let Some(insert) = &self.insert {
-            let mut sql = "INSERT INTO ".to_string();
-            sql.push_str(&insert.to_sql()?);
-            Ok(Some(SqlLiteral::new(sql)))
+            let mut collector = insert.to_sql()?;
+            collector.value = format!("INSERT INTO {}", &collector.value);
+            Ok(Some(collector))
         } else {
             Ok(None)
         }
